# LCV + RAFT

## Original code

- LCV: [https://github.com/Prinsphield/LCV](https://github.com/Prinsphield/LCV)
- RAFT: [https://github.com/princeton-vl/RAFT](https://github.com/princeton-vl/RAFT)

## Code license

- LCV: [LICENSE_LCV](LICENSE_LCV).
- RAFT: [LICENSE_RAFT](LICENSE_RAFT).

## Pretrained weights license

See [LICENSE_WEIGHTS](LICENSE_WEIGHTS).

## Citation

### LCV

```
@inproceedings{xiao2020learnable,
    title={Learnable cost volume using the cayley representation},
    author={Xiao, Taihong and Yuan, Jinwei and Sun, Deqing and Wang, Qifei and Zhang, Xin-Yu and Xu, Kehan and Yang, Ming-Hsuan},
    booktitle={European Conference on Computer Vision (ECCV)},
    pages={483--499},
    year={2020},
    organization={Springer}
}
```

### RAFT

```
@inproceedings{teed2020raft,
  title={Raft: Recurrent all-pairs field transforms for optical flow},
  author={Teed, Zachary and Deng, Jia},
  booktitle={European Conference on Computer Vision},
  pages={402--419},
  year={2020},
  organization={Springer}
}
```